import { environment } from '../../../../environments/environment';
import { Component, OnInit, OnDestroy, AfterViewInit } from '@angular/core';
import { NzMessageService } from 'ng-zorro-antd';
import { _HttpClient } from '@delon/theme';
import { HttpClient } from '@angular/common/http';
import * as moment from 'moment';
import { DeviceService } from '@business/services/http/device.service';
import * as echarts from 'echarts';

@Component({
    selector: 'environment-management',
    templateUrl: './management.component.html',
    styleUrls: ['./management.component.less'],
    providers: [DeviceService]
})
export class EnvironmentManagementComponent implements OnInit, OnDestroy {

    offlineChartData: any[] = [];

    constructor(
        private deviceService: DeviceService,
        private http: _HttpClient,
        public msg: NzMessageService,
        private http2: HttpClient) {
    }
  
    public option = {
      tooltip: {
        trigger: 'item',
        axisPointer: {
          type: 'cross'
        }
      },
      legend: {
        right: '10%',
        top: '10%',
        data: ['本月数据', '上月同期']
      },
      xAxis: {
        type: 'category',
        data: []
      },
      yAxis: {
        type: 'value',
        name: '单位：ug/m³'
      },
      series: [
        {
          data: [],
          type: 'line',
          smooth: true,
          name: '本月数据'
        }, {
          data: [],
          type: 'line',
          smooth: true,
          name: '上月同期'
        }
      ]
    };
  
    ngAfterViewInit() {
      const PM25 = echarts.init(document.getElementById('PM25'));
      PM25.showLoading();
      const params = {
        type: 'month',
        sensors: JSON.stringify(['e1']),
        items: JSON.stringify([
          {areaCode: 320583, formatTime: moment().format('YYYY-MM')},
          {areaCode: 320583, formatTime: moment().subtract(1, 'M').format('YYYY-MM')}
        ])
      };
      this.http2.get(environment.SERVER_BASH_URL + 'report/compare', {params: params}).subscribe((res: any) => {
        this.option.xAxis.data = res.data.times;
        this.option.series[0].data = res.data.datas[0]['e1'];
        this.option.series[1].data = res.data.datas[1]['e1'];
        PM25.setOption(this.option, false);
        window.onresize = PM25.resize;
        PM25.hideLoading();
      });
    }
    
    ngOnInit() {
    }

    ngOnDestroy(): void {
    }
}
